@@ -36,7 +36,8 @@
 #include <libxfce4ui/libxfce4ui.h>
 #include <libnotify/notify.h>
 
-#include "xfce4-notifyd/xfce-notify-log.h"
+#include <common/xfce-notify-log.h>
+
 #include "xfce4-notifyd-config.ui.h"
 
 #define KNOWN_APPLICATIONS_PROP       "/applications/known_applications"
@@ -572,13 +573,14 @@ xfce4_notifyd_log_populate (NotificationLogWidgets *log_widgets)
             const char *tooltip_format_simple = "<b>\%s</b> - \%s";
             char *markup;
             gchar *app_name;
-            gchar *tooltip_timestamp;
+            gchar *tooltip_timestamp = NULL;
             gchar *tmp;
             GTimeVal tv;
             GDateTime *log_timestamp;
 
             if (g_time_val_from_iso8601 (group, &tv) == TRUE) {
-                if (log_timestamp = g_date_time_new_from_timeval_local (&tv)) {
+                log_timestamp = g_date_time_new_from_timeval_local (&tv);
+                if (log_timestamp != NULL) {
                     tooltip_timestamp = g_date_time_format (log_timestamp, "%c");
                     g_date_time_unref(log_timestamp);
                 }
@@ -651,12 +653,22 @@ xfce4_notifyd_log_populate (NotificationLogWidgets *log_widgets)
             tmp = g_key_file_get_string (notify_log, group, "body", NULL);
             if (g_strcmp0 (tmp, "") == 0) {
                 gtk_grid_attach (GTK_GRID (grid), GTK_WIDGET (summary), 1, 0, 1, 2);
-                markup = g_strdup_printf (tooltip_format_simple, app_name, tooltip_timestamp);
+                if (tooltip_timestamp != NULL) {
+                    markup = g_strdup_printf (tooltip_format_simple, app_name, tooltip_timestamp);
+                }
+                else {
+                    markup = g_strdup_printf (format, app_name);
+                }
             }
             else {
                 gtk_grid_attach (GTK_GRID (grid), GTK_WIDGET (summary), 1, 0, 1, 1);
                 gtk_grid_attach (GTK_GRID (grid), GTK_WIDGET (body), 1, 1, 1, 1);
-                markup = g_strdup_printf (tooltip_format, app_name, tooltip_timestamp, tmp);
+                if (tooltip_timestamp != NULL) {
+                    markup = g_strdup_printf (tooltip_format_simple, app_name, tooltip_timestamp);
+                }
+                else {
+                    markup = g_strdup_printf (format, app_name);
+                }
             }
             g_free (tmp);
             g_free (app_name);
@@ -819,6 +831,8 @@ xfce4_notifyd_config_setup_dialog(GtkBuilder *builder)
     primary_monitor = GTK_WIDGET(gtk_builder_get_object(builder, "primary_monitor"));
     xfconf_g_property_bind(channel, "/primary-monitor", G_TYPE_UINT,
                            G_OBJECT(primary_monitor), "active");
+    if(gtk_combo_box_get_active(GTK_COMBO_BOX(primary_monitor)) == -1)
+        gtk_combo_box_set_active(GTK_COMBO_BOX(primary_monitor), 0);
 
     // Appearance
     theme_combo = GTK_WIDGET(gtk_builder_get_object(builder, "theme_combo"));
