@@ -39,11 +39,11 @@
 
 #include <xfconf/xfconf.h>
 
-#include "xfce-notify-gbus.h"
+#include <common/xfce-notify-log.h>
 
+#include "xfce-notify-gbus.h"
 #include "xfce-notify-daemon.h"
 #include "xfce-notify-window.h"
-#include "xfce-notify-log.h"
 #include "xfce-notify-marshal.h"
 
 #define SPACE 16
@@ -216,7 +216,7 @@ xfce_notify_daemon_get_primary_monitor (GdkScreen *screen)
 
     return xfce_notify_daemon_get_monitor_index (display, monitor);
 #else
-    return gdk_screen_get_primary_monitor(widget_screen);
+    return gdk_screen_get_primary_monitor (screen);
 #endif
 }
 
@@ -231,7 +231,7 @@ xfce_notify_daemon_get_monitor_at_point (GdkScreen *screen,
 
     return xfce_notify_daemon_get_monitor_index (display, monitor);
 #else
-    return gdk_screen_get_monitor_at_point(widget_screen);
+    return gdk_screen_get_monitor_at_point (screen, x, y);
 #endif
 }
 
@@ -1136,6 +1136,7 @@ notify_notify (XfceNotifyGBus *skeleton,
     XfceNotifyWindow *window;
     GdkPixbuf *pix = NULL;
     GVariant *image_data = NULL;
+    GVariant *icon_data = NULL;
     const gchar *image_path = NULL;
     gchar *desktop_id = NULL;
     gchar *new_app_name;
@@ -1170,16 +1171,22 @@ notify_notify (XfceNotifyGBus *skeleton,
             }
             g_variant_unref(value);
         }
-        else if ((g_strcmp0 (key, "image_data") == 0) ||
-                 (g_strcmp0 (key, "icon_data") == 0)  ||
-                 (g_strcmp0 (key, "image-data") == 0) ||
-                 (g_strcmp0 (key, "icon-data") == 0))
+        else if ((g_strcmp0 (key, "image-data") == 0) ||
+                 (g_strcmp0 (key, "image_data") == 0))
         {
             if (image_data) {
                 g_variant_unref(image_data);
             }
             image_data = value;
         }
+        else if ((g_strcmp0 (key, "icon-data") == 0) ||
+                 (g_strcmp0 (key, "icon_data") == 0))
+        {
+            if (icon_data) {
+                g_variant_unref(icon_data);
+            }
+            icon_data = value;
+        }
         else if ((g_strcmp0 (key, "image-path") == 0) ||
                  (g_strcmp0 (key, "image_path") == 0))
         {
@@ -1213,11 +1220,6 @@ notify_notify (XfceNotifyGBus *skeleton,
             x_canonical = TRUE;
             g_variant_unref(value);
         }
-        else if (g_strcmp0 (key, "urgency") == 0)
-        {
-            g_warning ("the urgency bit is set");
-            g_variant_unref(value);
-        }
         else
         {
             g_variant_unref(value);
@@ -1250,15 +1252,16 @@ notify_notify (XfceNotifyGBus *skeleton,
             if (xndaemon->notification_log == TRUE &&
                 transient == FALSE) {
                 /* Either log in DND mode or always for muted apps */
-                if (xndaemon->log_level == 0 && xndaemon->do_not_disturb == TRUE ||
+                if ((xndaemon->log_level == 0 && xndaemon->do_not_disturb == TRUE) ||
                     xndaemon->log_level == 1)
                       /* Log either all, all except muted or only muted applications */
                       if (xndaemon->log_level_apps == 0 ||
-                          xndaemon->log_level_apps == 1 && application_is_muted == FALSE ||
-                          xndaemon->log_level_apps == 2 && application_is_muted == TRUE)
+                          (xndaemon->log_level_apps == 1 && application_is_muted == FALSE) ||
+                          (xndaemon->log_level_apps == 2 && application_is_muted == TRUE)) {
                           xfce_notify_log_insert (new_app_name, summary, body,
                                                   image_data, image_path, app_icon,
                                                   desktop_id, expire_timeout, actions);
+                      }
             }
 
             xfce_notify_gbus_complete_notify (skeleton, invocation, OUT_id);
@@ -1315,7 +1318,7 @@ notify_notify (XfceNotifyGBus *skeleton,
 
     if (image_data) {
         pix = notify_pixbuf_from_image_data(image_data);
-        if(pix) {
+        if (pix) {
             xfce_notify_window_set_icon_pixbuf(window, pix);
             g_object_unref(G_OBJECT(pix));
         }
@@ -1326,6 +1329,13 @@ notify_notify (XfceNotifyGBus *skeleton,
     else if (app_icon && (g_strcmp0 (app_icon, "") != 0)) {
         xfce_notify_window_set_icon_name (window, app_icon);
     }
+    else if (icon_data) {
+        pix = notify_pixbuf_from_image_data(icon_data);
+        if (pix) {
+            xfce_notify_window_set_icon_pixbuf(window, pix);
+            g_object_unref(G_OBJECT(pix));
+        }
+    }
     else if (desktop_id) {
         xfce_notify_window_set_icon_name (window, notify_icon_name_from_desktop_id (desktop_id));
     }
@@ -1343,7 +1353,7 @@ notify_notify (XfceNotifyGBus *skeleton,
     xfce_notify_window_set_do_fadeout(window, xndaemon->do_fadeout, xndaemon->do_slideout);
     xfce_notify_window_set_notify_location(window, xndaemon->notify_location);
 
-    if(value_hint_set)
+    if (value_hint_set)
         xfce_notify_window_set_gauge_value(window, value_hint, xndaemon->css_provider);
     else
         xfce_notify_window_unset_gauge_value(window);
@@ -1352,12 +1362,13 @@ notify_notify (XfceNotifyGBus *skeleton,
 
     xfce_notify_gbus_complete_notify(skeleton, invocation, OUT_id);
 
-    g_free(new_app_name);
+    g_free (new_app_name);
     if (image_data)
-        g_variant_unref(image_data);
+      g_variant_unref (image_data);
+    if (icon_data)
+      g_variant_unref (icon_data);
     if (desktop_id)
-        g_free(desktop_id);
-
+        g_free (desktop_id);
     return TRUE;
 }
 
