@@ -173,7 +173,7 @@ static void
 xfce_notify_window_init(XfceNotifyWindow *window)
 {
     GdkScreen *screen;
-    GtkWidget *tophbox, *vbox;
+    GtkWidget *topvbox, *tophbox, *vbox;
     gint screen_width;
     gdouble padding = DEFAULT_PADDING;
 #if GTK_CHECK_VERSION (3, 22, 0)
@@ -217,7 +217,7 @@ xfce_notify_window_init(XfceNotifyWindow *window)
        screen as maximum width. */
 #if GTK_CHECK_VERSION (3, 22, 0)
     monitor = gdk_display_get_monitor_at_window (gtk_widget_get_display (GTK_WIDGET (window)),
-                                                 gtk_widget_get_window (GTK_WIDGET (window)));
+                                                 gdk_screen_get_root_window (screen));
     gdk_monitor_get_geometry (monitor, &geometry);
     screen_width = geometry.width / 30;
 #else
@@ -228,11 +228,15 @@ xfce_notify_window_init(XfceNotifyWindow *window)
                          "padding", &padding,
                          NULL);
 
-    tophbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+    topvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+    gtk_box_set_homogeneous (GTK_BOX (topvbox), FALSE);
+    gtk_container_set_border_width (GTK_CONTAINER(topvbox), padding);
+    gtk_widget_show (topvbox);
+    gtk_container_add (GTK_CONTAINER(window), topvbox);
+    tophbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_box_set_homogeneous (GTK_BOX (tophbox), FALSE);
-    gtk_container_set_border_width(GTK_CONTAINER(tophbox), padding);
-    gtk_widget_show(tophbox);
-    gtk_container_add(GTK_CONTAINER(window), tophbox);
+    gtk_widget_show (tophbox);
+    gtk_container_add (GTK_CONTAINER(topvbox), tophbox);
 
     window->icon_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_container_set_border_width(GTK_CONTAINER(window->icon_box), 0);
@@ -244,7 +248,7 @@ xfce_notify_window_init(XfceNotifyWindow *window)
     gtk_widget_show(window->icon);
     gtk_container_add(GTK_CONTAINER(window->icon_box), window->icon);
 
-    window->content_box = vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, padding / 2);
+    window->content_box = vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_box_set_homogeneous(GTK_BOX (vbox), FALSE);
     gtk_container_set_border_width(GTK_CONTAINER(vbox), 0);
     gtk_widget_show(vbox);
@@ -253,32 +257,35 @@ xfce_notify_window_init(XfceNotifyWindow *window)
     window->summary = gtk_label_new(NULL);
     gtk_widget_set_name (window->summary, "summary");
     gtk_label_set_max_width_chars (GTK_LABEL(window->summary), screen_width);
+    gtk_label_set_ellipsize (GTK_LABEL (window->summary), PANGO_ELLIPSIZE_END);
     gtk_label_set_line_wrap(GTK_LABEL(window->summary), TRUE);
 #if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL(window->summary), 0);
 #else
     gtk_widget_set_halign (window->summary, GTK_ALIGN_START);
 #endif
-    gtk_box_pack_start(GTK_BOX(vbox), window->summary, FALSE, FALSE, 0);
+    gtk_widget_set_valign (window->summary, GTK_ALIGN_BASELINE);
+    gtk_box_pack_start(GTK_BOX(vbox), window->summary, TRUE, TRUE, 0);
 
     window->body = gtk_label_new(NULL);
     gtk_widget_set_name (window->body, "body");
     gtk_label_set_max_width_chars (GTK_LABEL(window->body), screen_width);
+    gtk_label_set_ellipsize (GTK_LABEL (window->body), PANGO_ELLIPSIZE_END);
     gtk_label_set_line_wrap(GTK_LABEL(window->body), TRUE);
 #if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL(window->body), 0);
 #else
     gtk_widget_set_halign (window->body, GTK_ALIGN_START);
 #endif
-    gtk_widget_set_valign (window->body, GTK_ALIGN_START);
+    gtk_widget_set_valign (window->body, GTK_ALIGN_BASELINE);
     gtk_box_pack_start(GTK_BOX(vbox), window->body, TRUE, TRUE, 0);
 
     window->button_box = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
     gtk_button_box_set_layout(GTK_BUTTON_BOX(window->button_box),
                               GTK_BUTTONBOX_END);
-    gtk_box_set_spacing(GTK_BOX(window->button_box), padding / 2);
-    gtk_box_set_homogeneous(GTK_BOX(window->button_box), FALSE);
-    gtk_box_pack_start(GTK_BOX(vbox), window->button_box, FALSE, FALSE, 0);
+    gtk_box_set_spacing (GTK_BOX(window->button_box), padding / 2);
+    gtk_box_set_homogeneous (GTK_BOX(window->button_box), FALSE);
+    gtk_box_pack_end (GTK_BOX(topvbox), window->button_box, FALSE, FALSE, 0);
 }
 
 static void
@@ -969,6 +976,7 @@ xfce_notify_window_set_actions(XfceNotifyWindow *window,
         const gchar *cur_button_text = actions[i+1];
         GtkWidget *btn, *lbl;
         gchar *cur_button_text_escaped;
+        gdouble padding;
 
         if(!cur_button_text || !cur_action_id || !*cur_action_id)
             break;
@@ -980,11 +988,15 @@ xfce_notify_window_set_actions(XfceNotifyWindow *window,
         if (g_strcmp0 (cur_button_text, "") == 0)
             continue;
 
+        gtk_widget_style_get(GTK_WIDGET(window),
+                             "padding", &padding,
+                             NULL);
         btn = gtk_button_new();
         g_object_set_data_full(G_OBJECT(btn), "--action-id",
                                g_strdup(cur_action_id),
                                (GDestroyNotify)g_free);
         gtk_widget_show(btn);
+        gtk_widget_set_margin_top (btn, padding / 2);
         gtk_container_add(GTK_CONTAINER(window->button_box), btn);
         g_signal_connect(G_OBJECT(btn), "clicked",
                          G_CALLBACK(xfce_notify_window_button_clicked),
